# snmpy [![Build Status](https://travis-ci.org/SimplicityGuy/snmpy.svg?branch=master)](https://travis-ci.org/SimplicityGuy/snmpy)
## Simple pysnmp wrapper

The pysnmp library is somewhat tricky to work with. This package makes reading and writing
SNMP OIDs much easier.

This project is a fork and re-organization from the original python-snmpclient project.
